==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ServiceProviderCredentialsBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ServiceProviderCredentialsBuilder extends ServiceProviderCredentialsFluentImpl<ServiceProviderCredentialsBuilder> implements VisitableBuilder<ServiceProviderCredentials,ServiceProviderCredentialsBuilder>{
  public ServiceProviderCredentialsBuilder() {
    this(false);
  }
  public ServiceProviderCredentialsBuilder(Boolean validationEnabled) {
    this(new ServiceProviderCredentials(), validationEnabled);
  }
  public ServiceProviderCredentialsBuilder(ServiceProviderCredentialsFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceProviderCredentialsBuilder(ServiceProviderCredentialsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ServiceProviderCredentials(), validationEnabled);
  }
  public ServiceProviderCredentialsBuilder(ServiceProviderCredentialsFluent<?> fluent,ServiceProviderCredentials instance) {
    this(fluent, instance, false);
  }
  public ServiceProviderCredentialsBuilder(ServiceProviderCredentialsFluent<?> fluent,ServiceProviderCredentials instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAws(instance.getAws());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ServiceProviderCredentialsBuilder(ServiceProviderCredentials instance) {
    this(instance,false);
  }
  public ServiceProviderCredentialsBuilder(ServiceProviderCredentials instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAws(instance.getAws());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ServiceProviderCredentialsFluent<?> fluent;
  Boolean validationEnabled;
  public ServiceProviderCredentials build() {
    ServiceProviderCredentials buildable = new ServiceProviderCredentials(fluent.getAws());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ServiceProviderCredentialsBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ServiceProviderCredentialsBuilder extends ServiceProviderCredentialsFluent<ServiceProviderCredentialsBuilder> implements VisitableBuilder<ServiceProviderCredentials,ServiceProviderCredentialsBuilder>{
  public ServiceProviderCredentialsBuilder() {
    this(false);
  }
  public ServiceProviderCredentialsBuilder(Boolean validationEnabled) {
    this(new ServiceProviderCredentials(), validationEnabled);
  }
  public ServiceProviderCredentialsBuilder(ServiceProviderCredentialsFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceProviderCredentialsBuilder(ServiceProviderCredentialsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ServiceProviderCredentials(), validationEnabled);
  }
  public ServiceProviderCredentialsBuilder(ServiceProviderCredentialsFluent<?> fluent,ServiceProviderCredentials instance) {
    this(fluent, instance, false);
  }
  public ServiceProviderCredentialsBuilder(ServiceProviderCredentialsFluent<?> fluent,ServiceProviderCredentials instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ServiceProviderCredentials());

    if (instance != null) {
      fluent.withAws(instance.getAws());
      fluent.withAws(instance.getAws());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ServiceProviderCredentialsBuilder(ServiceProviderCredentials instance) {
    this(instance,false);
  }
  public ServiceProviderCredentialsBuilder(ServiceProviderCredentials instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ServiceProviderCredentials());

    if (instance != null) {
      this.withAws(instance.getAws());
      this.withAws(instance.getAws());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ServiceProviderCredentialsFluent<?> fluent;
  Boolean validationEnabled;
  public ServiceProviderCredentials build() {
    ServiceProviderCredentials buildable = new ServiceProviderCredentials(fluent.buildAws());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
